Class: Tasks
- Inherits:
-
Asgard::Base
- Object
- Thor
- Asgard::Base
- Tasks
- Defined in:
- lib/asgard/tasks.rb
Overview
Tasks is the single conventional entry point for all .loki files. It is pre-defined by the gem so .loki files never need to declare a class. Auxiliary *.loki files define modules which are imported into Tasks.
Method Summary
Methods inherited from Asgard::Base
footer, header, #help, method_added, #tree
Methods included from Asgard::Base::Registry
#_method_log, #inherited, #subclasses
Methods included from Asgard::Base::DependencyGraph
#_deps, #depends_on, #validate_deps!
Methods included from Asgard::Base::TaskDSL
#default_task, #desc, #dotenv, #helper, #no_negate
Methods included from Asgard::Base::Dispatch
#dep_result, #dep_results, included, #invoke_command