Class: Tasks

Inherits:
Asgard::Base show all
Defined in:
lib/asgard/tasks.rb

Overview

Tasks is the single conventional entry point for all .loki files. It is pre-defined by the gem so .loki files never need to declare a class. Auxiliary *.loki files define modules which are imported into Tasks.

Method Summary

Methods inherited from Asgard::Base

_build_dep_graph, _cond, _deps, _done, _ran_mutex, _reset_ran!, _running, default_task, depends_on, desc, dotenv, footer, header, #help, helper, inherited, method_added, no_negate, subclasses, validate_deps!

Methods included from Asgard::Shell

#sh, #shebang