Class: Tasks

Inherits:
Asgard::Base show all
Defined in:
lib/asgard/tasks.rb

Overview

Tasks is the single conventional entry point for all .loki files. It is pre-defined by the gem so .loki files never need to declare a class. Auxiliary *.loki files define modules which are imported into Tasks.

Instance Method Summary collapse

Methods inherited from Asgard::Base

_build_dep_graph, _cond, _deps, _done, _ran_mutex, _reset_ran!, _running, _vars, depends_on, dotenv, import, inherited, method_added, subclasses, validate_deps!, var

Methods included from Asgard::Shell

#sh, #shebang

Instance Method Details

#_auto_loadObject



19
20
21
# File 'lib/asgard/tasks.rb', line 19

def _auto_load
  # Consumed by run! before Thor dispatch — never called directly.
end

#_versionObject



25
26
27
28
# File 'lib/asgard/tasks.rb', line 25

def _version
  puts Asgard::VERSION
  exit
end