Class: Tasks

Inherits:
Asgard::Base show all
Defined in:
lib/asgard/tasks.rb

Overview

Tasks is the single conventional entry point for all .loki files. It is pre-defined by the gem so .loki files never need to declare a class. Auxiliary *.loki files define modules which are imported into Tasks.

Method Summary

Methods inherited from Asgard::Base

_build_dep_graph, _deps, _ran_mutex, _ran_tasks, _reset_ran!, _vars, depends_on, dotenv, import, inherited, method_added, subclasses, validate_deps!, var

Methods included from Asgard::Shell

#sh, #shebang